pub trait Sequence<'gc>: Collect {
type Output;
// Required method
fn step(&mut self, mc: MutationContext<'gc, '_>) -> Option<Self::Output>;
}Expand description
A trait that describes a sequence of actions to perform, in between which garbage collection may take place.
This trait is similar to the Future trait in that it is not designed to be used directly, but
rather chained together using combinators and run to completion with a sequencer.
Required Associated Types
Required Methods
fn step(&mut self, mc: MutationContext<'gc, '_>) -> Option<Self::Output>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".